Resources
````````````````
* Follow the style of the :ref:`Ansible Documentation<ansible_documentation>`
* Ask for advice on IRC, on the ``#ansible-devel`` Freenode channel
* Review these online style guides:

  * `AP Stylebook <https://www.apstylebook.com>`_
  * `Chicago Manual of Style <http://www.chicagomanualofstyle.org/home.html>`_
  * `Strunk and White's Elements of Style <https://www.crockford.com/wrrrld/style.html>`_

